@@ -1,9 +1,8 @@
 optiallo <-
-function(n,x,y=x,stratum) {
-  SyUh2  <- as.vector(by(y,stratum,var))
+function(n,x,stratum=NULL,...) {
+  if (is.null(stratum)) {stratum<- stratify(x,...)}
   SxUh   <- as.vector(by(x,stratum,sd))
   SxUh[is.na(SxUh)]  <- sum(SxUh,na.rm=TRUE)
-  SyUh2[is.na(SyUh2)]<- 0
   if (min(SxUh)==0&max(SxUh)==0) {SxUh<- SxUh+1}
   Nh     <- as.vector(by(x,stratum,length))
   nh     <- n*Nh*SxUh/sum(Nh*SxUh)
@@ -18,6 +17,6 @@ function(n,x,y=x,stratum) {
     nhcor <- ncor*Nh*SxUh2/sum(Nh*SxUh2,na.rm=TRUE)
     nh    <- ifelse(is.na(nhcor),Nh,nhcor)
   }
-  salida<- sum(((Nh^2)/nh)*(1-(nh/Nh))*SyUh2)
-  salida
+  nh<- nh[stratum]
+  list(stratum=stratum,nh=nh)
 }
